==> dd_js_util-3.5.5.tar.gz: lib/util/dialog.dart <==
part of dd_js_util;

@Doc(message: "简单toast弹窗")
void showToast(String msg) {
  SmartDialog.showToast(msg);
}

@Doc(message: '显示一个iOS弹窗')
void showIosDialog(String msg,
    {String? okText,
    List<Widget>? startActions,
    List<Widget>? endActions,
    Widget? title}) {
  const tag = 's-dialog-simple-ok-btn';
  SmartDialog.show(
      builder: (_) {
        final isIos = io.Platform.isIOS;
        if (isIos) {
          return CupertinoAlertDialog(
            content: Text(msg),
            actions: [
              if (startActions != null) ...startActions,
              CupertinoDialogAction(
                  child: const Text("Ok"),
                  onPressed: () => SmartDialog.dismiss(tag: tag)),
              if (endActions != null) ...endActions
            ],
          );
        } else {
          final allEmpty = startActions == null && endActions == null;
          return AlertDialog(
            title: title ?? const Text(''),
            content: Text(msg),
            actions: allEmpty
                ? [
                    Row(
                      children: [
                        ElevatedButton(
                            onPressed: () => SmartDialog.dismiss(tag: tag),
                            child: Text(okText ?? "OK")).center
                      ],
                    )
                  ]
                : [
                    if (startActions != null) ...startActions,
                    ElevatedButton(
                        onPressed: () => SmartDialog.dismiss(tag: tag),
                        child: Text(okText ?? "OK")),
                    if (endActions != null) ...endActions
                  ],
          );
        }
      },
      tag: tag);
}

==> dd_js_util-4.1.2.tar.gz: lib/util/dialog.dart <==
part of dd_js_util;

@Doc(message: "简单toast弹窗")
void showToast(String msg) {
  SmartDialog.showToast(msg);
}

@Doc(message: '显示一个iOS弹窗')
void showIosDialog(String msg,
    {String okText = 'Ok',
    List<Widget>? startActions,
    List<Widget>? endActions,
    Widget? title,
    String cancelText = 'Cancel',
      Widget? content
    }) {
  const tag = 's-dialog-simple-ok-btn';
  SmartDialog.show(
      builder: (_) {
        final isIos = io.Platform.isIOS;
        if (isIos) {
          return CupertinoAlertDialog(
            content: Text(msg),
            actions: [
              if (startActions != null) ...startActions,
              CupertinoDialogAction(
                  child: const Text("Ok"),
                  onPressed: () => SmartDialog.dismiss(tag: tag)),
              if (endActions != null) ...endActions
            ],
          );
        } else {
          final allEmpty = startActions == null && endActions == null;
          return AlertDialog(
            title: title ?? const Text(''),
            content: content ?? Text(msg),
            actions: allEmpty
                ? [
                    Row(
                      mainAxisAlignment: MainAxisAlignment.end,
                      children: [
                        TextButton(onPressed: (){
                          SmartDialog.dismiss(tag: tag);
                        }, child: Text(cancelText)),
                        FilledButton(
                            onPressed: () => SmartDialog.dismiss(tag: tag),
                            child: Text(okText)).center
                      ],
                    )
                  ]
                : [
                    if (startActions != null) ...startActions,
                    ElevatedButton(
                        onPressed: () => SmartDialog.dismiss(tag: tag),
                        child: Text(okText)),
                    if (endActions != null) ...endActions
                  ],
          );
        }
      },
      tag: tag);
}
